@@ -33,18 +33,20 @@ package Apache2::AMFLiteDetectionFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "4.09";;;
+  $VERSION= "4.10";;;
   my $CommonLib = new Apache2::AMFCommonLib ();
   my %MobileArray;#=$CommonLib->getMobileArray;
   my %MobileTabletArray;
   my %MobileTouchArray;
+  my %MobileTVArray;
   my $cookiecachesystem="false";
   my $restmode='false';
-  my $downloadparamurl='true';
+  my $downloadparam='true';
   my $configMobileFile;
   my $forcetablet='true';
   my $configTabletFile;
   my $configTouchFile;
+  my $configTVFile;
   my $checkVersion='true';
   my $mobilenable="false";
   my $hostNames = "sourceforge.net";
@@ -56,6 +58,7 @@ package Apache2::AMFLiteDetectionFilter;
   my $urlmobile=$hostServer."litemobiledetection.config/download";
   my $urlTablet=$hostServer."litetabletdetection.config/download";
   my $urlTouch=$hostServer."litetouchdetection.config/download";
+  my $urlTv=$hostServer."litetvdetection.config/download";
   my $urlBot=$hostServer."litebotdetection.config/download";
   my $forceBlockDownload="false";
   my $ua=LWP::UserAgent->new;
@@ -78,7 +81,7 @@ package Apache2::AMFLiteDetectionFilter;
       }
       $CommonLib->printLog("AMFSetHttpProxyPort is ".$port.$default);
       $ua->proxy('http','http://'.$ENV{AMFSetHttpProxy}.':'.$port);
-      $ua->proxy('https','https://'.$ENV{AMFSetHttpProxy}.':'.$port);
+      $ua->proxy('https','http://'.$ENV{AMFSetHttpProxy}.':'.$port);
   }
   my $timeoutinsecond=5;
   my $default="";
@@ -96,6 +99,7 @@ package Apache2::AMFLiteDetectionFilter;
 	  $configMobileFile="$ENV{AMFMobileHome}/amflitedetection.config";
 	  $configTabletFile="$ENV{AMFMobileHome}/amflitedetection_tablet.config";
 	  $configTouchFile="$ENV{AMFMobileHome}/amflitedetection_touch.config";
+	  $configTVFile="$ENV{AMFMobileHome}/amflitedetection_tv.config";
    }  else {
 	  $CommonLib->printLog("AMFMobileHome not exist. Please set the variable AMFMobileHome into httpd.conf");
 	  ModPerl::Util::exit();
@@ -117,18 +121,20 @@ package Apache2::AMFLiteDetectionFilter;
 			$restmode=$ENV{RestMode};
 			$CommonLib->printLog("RestMode is: $restmode");
     }
-    if ($ENV{AMFDownloadParamURL}) {
-	                        $downloadparamurl=$ENV{AMFDownloadParamURL};
-                            $CommonLib->printLog("DownloadAMFParamURL is: $downloadparamurl");
+    if ($ENV{AMFDownloadParam}) {
+	                        $downloadparam=$ENV{AMFDownloadParam};
+                            $CommonLib->printLog("DownloadAMFParam is: $downloadparam");
     }
-    if ($downloadparamurl eq 'true' && $forceBlockDownload eq "false") {
+    if ($downloadparam eq 'true' && $forceBlockDownload eq "false") {
         &readMobileParamFromUrl;	
         &readTabletParamFromUrl;
         &readTouchParamFromUrl;
+        &readTVParamFromUrl;
     } else {
-	&readMobileParamFromFile;		
+   	    &readMobileParamFromFile;		
         &readTabletParamFromFile;
         &readTouchParamFromFile;
+        &readTVParamFromFile;
     }
     if ($ENV{ForceTabletAsFullBrowser}) {
 		if ($ENV{ForceTabletAsFullBrowser} eq 'true') {
@@ -153,27 +159,29 @@ sub readMobileParamFromUrl {
         
         if ($res->is_success) {
             $CommonLib->printLog("Redirect to:" . $res->request()->uri());
-            $urlmobile=$urlmobile;
+            $urlmobile=$res->request()->uri();
+            my $request = $ua->get ($urlmobile);
+            my $content=$request->content;
+            if ($content) {
+                $CommonLib->printLog("Download OK");
+                $content =~ s/\n//g;
+                my @dummyMobileKeys = split(/,/, lc($content));
+                foreach my $dummy (@dummyMobileKeys) {
+                    $MobileArray{$dummy}='mobile';
+                }
+                 open (MYFILE, ">$configMobileFile") || die ("Cannot Open File: $configMobileFile");
+                    print MYFILE $content;
+                 close (MYFILE);
+             } else {
+                $CommonLib->printLog("Download error ".$correctHostName);
+                $CommonLib->printLog("Try download previews version");
+                &readMobileParamFromFile;	
+            }
         } else {
-            $CommonLib->printLog("Error: " . $res->status_line);
+                $CommonLib->printLog("Download error ".$correctHostName);
+                $CommonLib->printLog("Try download previews version");
+                &readMobileParamFromFile;	
         }
-		my $request = $ua->get ($urlmobile);
-        my $content=$request->content;
-		if ($content) {
-			$CommonLib->printLog("Download OK");
-			$content =~ s/\n//g;
-			my @dummyMobileKeys = split(/,/, lc($content));
-			foreach my $dummy (@dummyMobileKeys) {
-				$MobileArray{$dummy}='mobile';
-			}
-			 open (MYFILE, ">$configMobileFile") || die ("Cannot Open File: $configMobileFile");
-			    print MYFILE $content;
-			 close (MYFILE);
-		 } else {
-			$CommonLib->printLog("Download error ".$correctHostName);
-			$CommonLib->printLog("Try download previews version");
-			&readMobileParamFromFile;	
-		}
 }
 sub readMobileParamFromFile {
 		$CommonLib->printLog("Read for mobile data from $configMobileFile");
@@ -203,31 +211,34 @@ sub readTabletParamFromUrl {
         
         if ($res->is_success) {
             $CommonLib->printLog("Redirect to:" . $res->request()->uri());
-            $urlTablet=$urlTablet;
+            $urlTablet=$res->request()->uri();
+            my $request = $ua->get ($urlTablet);
+            my $content=$request->content;
+            if ($content) {
+                $CommonLib->printLog("Download OK");
+                $content =~ s/\n//g;
+                my @dummyMobileKeys = split(/,/, lc($content));
+                foreach my $dummy (@dummyMobileKeys) {
+                    $MobileTabletArray{$dummy}='mobile';
+                }
+                 open (MYFILE, ">$configTabletFile") || die ("Cannot Open File: $configMobileFile");
+                    print MYFILE $content;
+                 close (MYFILE);
+             } else {
+                $CommonLib->printLog("Download error from ".$correctHostName);
+                $CommonLib->printLog("Try download previews version");
+                &readTabletParamFromFile;	
+            }
         } else {
             $CommonLib->printLog("Error: " . $res->status_line);
+            $CommonLib->printLog("Download error from ".$correctHostName);
+            $CommonLib->printLog("Try download previews version");
+            &readTabletParamFromFile;	
         }
         
-		my $request = $ua->get ($urlTablet);
-        my $content=$request->content;
-		if ($content) {
-			$CommonLib->printLog("Download OK");
-			$content =~ s/\n//g;
-			my @dummyMobileKeys = split(/,/, lc($content));
-			foreach my $dummy (@dummyMobileKeys) {
-				$MobileTabletArray{$dummy}='mobile';
-			}
-			 open (MYFILE, ">$configTabletFile") || die ("Cannot Open File: $configMobileFile");
-			    print MYFILE $content;
-			 close (MYFILE);
-		 } else {
-			$CommonLib->printLog("Download error from ".$correctHostName);
-			$CommonLib->printLog("Try download previews version");
-			&readTabletParamFromFile;	
-		}
 }
 sub readTabletParamFromFile {
-		$CommonLib->printLog("Read data from $configTabletFile");
+		$CommonLib->printLog("Read for tablet data from $configTabletFile");
 		my $content="";
 		if (open (IN,$configTabletFile)) {
 			while (<IN>) {
@@ -245,7 +256,7 @@ sub readTabletParamFromFile {
 		}
 }
 sub readTouchParamFromUrl {
-		$CommonLib->printLog("Read data for touch detection from ".$urlTouch);
+		$CommonLib->printLog("Read for touch data for touch detection from ".$urlTouch);
         my $req = HTTP::Request->new(HEAD => $urlTouch);
         $req->header('Accept' => 'text/html');
         
@@ -254,27 +265,30 @@ sub readTouchParamFromUrl {
         if ($res->is_success) {
             $CommonLib->printLog("Redirect to:" . $res->request()->uri());
             $urlmobile=$urlmobile;
+            my $request = $ua->get ($urlTouch);
+            my $content=$request->content;
+    
+            if ($content) {
+                $CommonLib->printLog("Download OK");
+                $content =~ s/\n//g;
+                my @dummyMobileKeys = split(/,/, lc($content));
+                foreach my $dummy (@dummyMobileKeys) {
+                    $MobileTouchArray{$dummy}='mobile';
+                }
+                 open (MYFILE, ">$configTouchFile") || die ("Cannot Open File: $configMobileFile");
+                    print MYFILE $content;
+                 close (MYFILE);
+             } else {
+                $CommonLib->printLog("Download error from ".$correctHostName);
+                $CommonLib->printLog("Try download previews version");
+                &readTouchParamFromFile;	
+            }
         } else {
             $CommonLib->printLog("Error: " . $res->status_line);
+            $CommonLib->printLog("Download error from ".$correctHostName);
+            $CommonLib->printLog("Try download previews version");
+            &readTouchParamFromFile;	
         }
-        my $request = $ua->get ($urlTouch);
-        my $content=$request->content;
-
-		if ($content) {
-			$CommonLib->printLog("Download OK");
-			$content =~ s/\n//g;
-			my @dummyMobileKeys = split(/,/, lc($content));
-			foreach my $dummy (@dummyMobileKeys) {
-				$MobileTouchArray{$dummy}='mobile';
-			}
-			 open (MYFILE, ">$configTouchFile") || die ("Cannot Open File: $configMobileFile");
-			    print MYFILE $content;
-			 close (MYFILE);
-		 } else {
-			$CommonLib->printLog("Download error from ".$correctHostName);
-			$CommonLib->printLog("Try download previews version");
-			&readTouchParamFromFile;	
-		}
 }
 sub readTouchParamFromFile {
 		$CommonLib->printLog("Read data from $configTouchFile");
@@ -294,7 +308,59 @@ sub readTouchParamFromFile {
 			$MobileTouchArray{$dummy}='mobile';
 		}
 }
-
+sub readTVParamFromUrl {
+		$CommonLib->printLog("Read data for TV detection from ".$urlTv);
+        my $req = HTTP::Request->new(HEAD => $urlTv);
+        $req->header('Accept' => 'text/html');
+        
+        my $res = $ua->request($req);
+        
+        if ($res->is_success) {
+            $CommonLib->printLog("Redirect to:" . $res->request()->uri());
+            $urlmobile= $res->request()->uri();
+            my $request = $ua->get ($urlTv);
+            my $content=$request->content;
+    
+            if ($content) {
+                $CommonLib->printLog("Download OK");
+                $content =~ s/\n//g;
+                my @dummyMobileKeys = split(/,/, lc($content));
+                foreach my $dummy (@dummyMobileKeys) {
+                    $MobileTVArray{$dummy}='mobile';
+                }
+                 open (MYFILE, ">$configTVFile") || die ("Cannot Open File: $configTVFile");
+                    print MYFILE $content;
+                 close (MYFILE);
+             } else {
+                $CommonLib->printLog("Download error from ".$correctHostName);
+                $CommonLib->printLog("Try download previews version");
+                &readTVParamFromFile;	
+            }
+        } else {
+            $CommonLib->printLog("Error: " . $res->status_line);
+            $CommonLib->printLog("Download error from ".$correctHostName);
+            $CommonLib->printLog("Try download previews version");
+            &readTVParamFromFile;	
+        }
+}
+sub readTVParamFromFile {
+		$CommonLib->printLog("Read for tv data from $configTVFile");
+		my $content="";
+		if (open (IN,$configTVFile)) {
+			while (<IN>) {
+				$content=$content.$_;				 
+			}
+			close IN;
+		} else {
+			$CommonLib->printLog("Error open file:$configTVFile");
+			ModPerl::Util::exit();
+		}
+                $content =~ s/\n//g;
+		my @dummyMobileKeys = split(/,/, lc($content));
+		foreach my $dummy (@dummyMobileKeys) {
+			$MobileTVArray{$dummy}='mobile';
+		}
+}
 sub isMobile {
   my ($UserAgent) = @_;
   my $ind=0;
@@ -334,6 +400,19 @@ sub isTouch {
   }
   return $isTouchValue;
 }
+sub isTV {
+  my ($UserAgent) = @_;
+  my $ind=0;
+  my $isTVValue='false';
+  my $pair;
+  my $length=0;
+  foreach $pair (sort keys %MobileTVArray) {
+	if ($UserAgent =~ m/$pair/) {
+		$isTVValue='true';
+	}
+  }
+  return $isTVValue;
+}
 sub cleanUA {
   my ($UserAgent) = @_;
   $UserAgent =~ s/google favicon//g;
@@ -417,6 +496,7 @@ sub handler {
     my $amf_device_istablet='false';
     my $amf_device_istouch='false';
     my $amf_device_ismobile='';
+    my $amf_device_istv='';
     my $version="";
     my $amf_device_os='nc';
     my $amf_device_os_version='nc';
@@ -467,6 +547,7 @@ sub handler {
             $amf_device_os=&getOperativeSystem($user_agent);
             $amf_device_os_version=&getOperativeSystemVersion($user_agent,$amf_device_os);            
 		}
+		$amf_device_istv = &isTV($user_agent);
 		if ($cookiecachesystem eq "true") {
 			$f->err_headers_out->set('Set-Cookie' => "amfID=$id; path=/;");	
 		}	
@@ -482,6 +563,7 @@ sub handler {
 	$f->subprocess_env("AMF_DEVICE_IS_MOBILE" => $amf_device_ismobile);
 	$f->subprocess_env("AMF_DEVICE_IS_TABLET" => $amf_device_istablet);
 	$f->subprocess_env("AMF_DEVICE_IS_TOUCH" => $amf_device_istouch);
+	$f->subprocess_env("AMF_DEVICE_IS_TV" => $amf_device_istv);
 	$f->subprocess_env("AMF_DEVICE_MOBILE_OS" => $amf_device_os);
 	$f->subprocess_env("AMF_DEVICE_MOBILE_OS_VERSION" => $amf_device_os_version);
     
